# url API
URL = 'https://api.openweathermap.org/data/2.5/'

# Opciones de reporte (Actual o previsión de los próximos 5 días)
ACTUAL = 'weather?'
PREVISION = 'forecast?'

# Códigos de lenguajes que se pueden pasar a la API.
CODIGO_LENGUAJE = {
    'es': 'Spanish',
    'en': 'English'
}
